Documentation
¶
Index ¶
- Constants
- Variables
- func AmazonProvider(cfg amazon.Config) (core.Provider, error)
- func CalendarProvider(cfg calendar.Config) (core.Provider, error)
- func DocsProvider(cfg docs.Config) (core.Provider, error)
- func DriveProvider(cfg drive.Config) (core.Provider, error)
- func FacebookProvider(cfg facebook.Config) (core.Provider, error)
- func GetCoreMigrationsFS() fs.FS
- func GetMigrationsFS() fs.FS
- func GitHubProvider(cfg github.Config) (core.Provider, error)
- func GmailProvider(cfg gmail.Config) (core.Provider, error)
- func GoogleShoppingProvider(cfg shopping.Config) (core.Provider, error)
- func InstagramProvider(cfg instagram.Config) (core.Provider, error)
- func PinterestProvider(cfg pinterest.Config) (core.Provider, error)
- func SalesforceProvider(cfg salesforce.Config) (core.Provider, error)
- func ShopifyProvider(cfg shopify.Config) (core.Provider, error)
- func TikTokProvider(cfg tiktok.Config) (core.Provider, error)
- func WorkdayProvider(cfg workday.Config) (core.Provider, error)
- type CallbackURLResolveFlow
- type CallbackURLResolveRequest
- type CallbackURLResolver
- type CallbackURLResolverFunc
- type CapabilityDescriptorPack
- type CommandQueryBundleFactory
- type CommandQueryService
- type Commands
- type CompleteAuthRequest
- type Config
- type ConnectRequest
- type ConnectionLocker
- type CreateSyncJobRequest
- type CreateSyncJobResult
- type CredentialCodec
- type EmbeddedAccessToken
- type EmbeddedAuthRequest
- type EmbeddedAuthResult
- type EmbeddedAuthService
- type EmbeddedRequestedTokenType
- type EmbeddedSessionClaims
- type ExtensionHooks
- func (h *ExtensionHooks) ApplyProviderPacks(registry core.Registry) error
- func (h *ExtensionHooks) BuildCommandQueryBundles(service CommandQueryService) (map[string]any, error)
- func (h *ExtensionHooks) BundleNames() []string
- func (h *ExtensionHooks) CapabilityDescriptors(providerID string) []core.CapabilityDescriptor
- func (h *ExtensionHooks) ProviderPacks() []ProviderPack
- func (h *ExtensionHooks) RegisterCapabilityPack(pack CapabilityDescriptorPack) error
- func (h *ExtensionHooks) RegisterCommandQueryBundle(name string, factory CommandQueryBundleFactory) error
- func (h *ExtensionHooks) RegisterProviderPack(pack ProviderPack) error
- type Facade
- type FacadeOption
- type GetSyncJobRequest
- type GrantStore
- type GrantStoreTransactional
- type IdempotencyClaimStore
- type InheritanceConfig
- type InstallationStore
- type InvokeCapabilityRequest
- type MetricsRecorder
- type OAuthStateStore
- type Option
- type PermissionEvaluator
- type ProviderPack
- type Queries
- type RateLimitPolicy
- type ReconsentRequest
- type RefreshBackoffScheduler
- type RefreshRequest
- type RefreshRunOptions
- type RefreshRunResult
- type SecretProvider
- type Service
- type ServiceDependencies
- type Signer
- type SubscriptionStore
- type SyncCursorStore
- type SyncJobStore
- type TransportResolver
Constants ¶
const ( CallbackURLResolveFlowConnect = core.CallbackURLResolveFlowConnect CallbackURLResolveFlowReconsent = core.CallbackURLResolveFlowReconsent EmbeddedRequestedTokenTypeOffline = core.EmbeddedRequestedTokenTypeOffline EmbeddedRequestedTokenTypeOnline = core.EmbeddedRequestedTokenTypeOnline )
Variables ¶
var ( WithLogger = core.WithLogger WithLoggerProvider = core.WithLoggerProvider WithMetricsRecorder = core.WithMetricsRecorder WithErrorFactory = core.WithErrorFactory WithErrorMapper = core.WithErrorMapper WithSecretProvider = core.WithSecretProvider WithPersistenceClient = core.WithPersistenceClient WithRepositoryFactory = core.WithRepositoryFactory WithConfigProvider = core.WithConfigProvider WithOptionsResolver = core.WithOptionsResolver WithOAuthStateStore = core.WithOAuthStateStore WithConnectionLocker = core.WithConnectionLocker WithRefreshBackoffScheduler = core.WithRefreshBackoffScheduler WithTransportResolver = core.WithTransportResolver WithRateLimitPolicy = core.WithRateLimitPolicy WithInheritancePolicy = core.WithInheritancePolicy WithRegistry = core.WithRegistry WithConnectionStore = core.WithConnectionStore WithCredentialStore = core.WithCredentialStore WithSubscriptionStore = core.WithSubscriptionStore WithSyncCursorStore = core.WithSyncCursorStore WithInstallationStore = core.WithInstallationStore WithSyncJobStore = core.WithSyncJobStore WithGrantStore = core.WithGrantStore WithPermissionEvaluator = core.WithPermissionEvaluator WithSigner = core.WithSigner WithCredentialCodec = core.WithCredentialCodec WithCallbackURLResolver = core.WithCallbackURLResolver )
Functions ¶
func FacebookProvider ¶ added in v0.2.0
func GetCoreMigrationsFS ¶
GetCoreMigrationsFS returns the default core services schema migration tree.
v1 intentionally ships only core migrations; segmented getters are deferred.
func GetMigrationsFS ¶
GetMigrationsFS returns the full embedded migration tree.
func GoogleShoppingProvider ¶ added in v0.2.0
func InstagramProvider ¶ added in v0.2.0
func PinterestProvider ¶ added in v0.2.0
func SalesforceProvider ¶ added in v0.2.0
func SalesforceProvider(cfg salesforce.Config) (core.Provider, error)
func ShopifyProvider ¶ added in v0.2.0
Types ¶
type CallbackURLResolveFlow ¶ added in v0.2.0
type CallbackURLResolveFlow = core.CallbackURLResolveFlow
type CallbackURLResolveRequest ¶ added in v0.2.0
type CallbackURLResolveRequest = core.CallbackURLResolveRequest
type CallbackURLResolver ¶ added in v0.2.0
type CallbackURLResolver = core.CallbackURLResolver
type CallbackURLResolverFunc ¶ added in v0.2.0
type CallbackURLResolverFunc = core.CallbackURLResolverFunc
type CapabilityDescriptorPack ¶
type CapabilityDescriptorPack struct {
Name string
ProviderID string
Descriptors []core.CapabilityDescriptor
}
type CommandQueryBundleFactory ¶
type CommandQueryBundleFactory func(service CommandQueryService) (any, error)
type CommandQueryService ¶
type CommandQueryService interface {
servicescommand.MutatingService
servicesquery.SyncCursorReader
servicesquery.InstallationReader
}
type Commands ¶
type Commands struct {
Connect *servicescommand.ConnectCommand
StartReconsent *servicescommand.StartReconsentCommand
CompleteReconsent *servicescommand.CompleteReconsentCommand
CompleteCallback *servicescommand.CompleteCallbackCommand
Refresh *servicescommand.RefreshCommand
Revoke *servicescommand.RevokeCommand
InvokeCapability *servicescommand.InvokeCapabilityCommand
Subscribe *servicescommand.SubscribeCommand
RenewSubscription *servicescommand.RenewSubscriptionCommand
CancelSubscription *servicescommand.CancelSubscriptionCommand
AdvanceSyncCursor *servicescommand.AdvanceSyncCursorCommand
UpsertInstallation *servicescommand.UpsertInstallationCommand
UpdateInstallation *servicescommand.UpdateInstallationStatusCommand
CreateSyncJob *servicescommand.CreateSyncJobCommand
}
type CompleteAuthRequest ¶
type CompleteAuthRequest = core.CompleteAuthRequest
type ConnectRequest ¶
type ConnectRequest = core.ConnectRequest
type ConnectionLocker ¶
type ConnectionLocker = core.ConnectionLocker
type CreateSyncJobRequest ¶ added in v0.2.0
type CreateSyncJobRequest = core.CreateSyncJobRequest
type CreateSyncJobResult ¶ added in v0.2.0
type CreateSyncJobResult = core.CreateSyncJobResult
type CredentialCodec ¶
type CredentialCodec = core.CredentialCodec
type EmbeddedAccessToken ¶ added in v0.3.0
type EmbeddedAccessToken = core.EmbeddedAccessToken
type EmbeddedAuthRequest ¶ added in v0.3.0
type EmbeddedAuthRequest = core.EmbeddedAuthRequest
type EmbeddedAuthResult ¶ added in v0.3.0
type EmbeddedAuthResult = core.EmbeddedAuthResult
type EmbeddedAuthService ¶ added in v0.3.0
type EmbeddedAuthService = core.EmbeddedAuthService
type EmbeddedRequestedTokenType ¶ added in v0.3.0
type EmbeddedRequestedTokenType = core.EmbeddedRequestedTokenType
type EmbeddedSessionClaims ¶ added in v0.3.0
type EmbeddedSessionClaims = core.EmbeddedSessionClaims
type ExtensionHooks ¶
type ExtensionHooks struct {
// contains filtered or unexported fields
}
func NewExtensionHooks ¶
func NewExtensionHooks() *ExtensionHooks
func (*ExtensionHooks) ApplyProviderPacks ¶
func (h *ExtensionHooks) ApplyProviderPacks(registry core.Registry) error
func (*ExtensionHooks) BuildCommandQueryBundles ¶
func (h *ExtensionHooks) BuildCommandQueryBundles( service CommandQueryService, ) (map[string]any, error)
func (*ExtensionHooks) BundleNames ¶
func (h *ExtensionHooks) BundleNames() []string
func (*ExtensionHooks) CapabilityDescriptors ¶
func (h *ExtensionHooks) CapabilityDescriptors(providerID string) []core.CapabilityDescriptor
func (*ExtensionHooks) ProviderPacks ¶
func (h *ExtensionHooks) ProviderPacks() []ProviderPack
func (*ExtensionHooks) RegisterCapabilityPack ¶
func (h *ExtensionHooks) RegisterCapabilityPack(pack CapabilityDescriptorPack) error
func (*ExtensionHooks) RegisterCommandQueryBundle ¶
func (h *ExtensionHooks) RegisterCommandQueryBundle( name string, factory CommandQueryBundleFactory, ) error
func (*ExtensionHooks) RegisterProviderPack ¶
func (h *ExtensionHooks) RegisterProviderPack(pack ProviderPack) error
type Facade ¶
type Facade struct {
// contains filtered or unexported fields
}
func NewFacade ¶
func NewFacade(service CommandQueryService, opts ...FacadeOption) (*Facade, error)
func (*Facade) Service ¶
func (f *Facade) Service() CommandQueryService
type FacadeOption ¶
type FacadeOption func(*facadeOptions)
func WithActivityReader ¶
func WithActivityReader(reader servicesquery.ServicesActivityReader) FacadeOption
type GetSyncJobRequest ¶ added in v0.2.0
type GetSyncJobRequest = core.GetSyncJobRequest
type GrantStore ¶
type GrantStore = core.GrantStore
type GrantStoreTransactional ¶
type GrantStoreTransactional = core.GrantStoreTransactional
type IdempotencyClaimStore ¶
type IdempotencyClaimStore = core.IdempotencyClaimStore
type InheritanceConfig ¶
type InheritanceConfig = core.InheritanceConfig
type InstallationStore ¶
type InstallationStore = core.InstallationStore
type InvokeCapabilityRequest ¶
type InvokeCapabilityRequest = core.InvokeCapabilityRequest
type MetricsRecorder ¶
type MetricsRecorder = core.MetricsRecorder
type OAuthStateStore ¶
type OAuthStateStore = core.OAuthStateStore
type PermissionEvaluator ¶
type PermissionEvaluator = core.PermissionEvaluator
type ProviderPack ¶
type Queries ¶
type Queries struct {
LoadSyncCursor *servicesquery.LoadSyncCursorQuery
ListServicesActivity *servicesquery.ListServicesActivityQuery
GetInstallation *servicesquery.GetInstallationQuery
ListInstallations *servicesquery.ListInstallationsQuery
GetSyncJob *servicesquery.GetSyncJobQuery
}
type RateLimitPolicy ¶
type RateLimitPolicy = core.RateLimitPolicy
type ReconsentRequest ¶
type ReconsentRequest = core.ReconsentRequest
type RefreshBackoffScheduler ¶
type RefreshBackoffScheduler = core.RefreshBackoffScheduler
type RefreshRequest ¶
type RefreshRequest = core.RefreshRequest
type RefreshRunOptions ¶
type RefreshRunOptions = core.RefreshRunOptions
type RefreshRunResult ¶
type RefreshRunResult = core.RefreshRunResult
type SecretProvider ¶
type SecretProvider = core.SecretProvider
type ServiceDependencies ¶
type ServiceDependencies = core.ServiceDependencies
type SubscriptionStore ¶
type SubscriptionStore = core.SubscriptionStore
type SyncCursorStore ¶
type SyncCursorStore = core.SyncCursorStore
type SyncJobStore ¶ added in v0.2.0
type SyncJobStore = core.SyncJobStore
type TransportResolver ¶
type TransportResolver = core.TransportResolver
Source Files
¶
Directories
¶
| Path | Synopsis |
|---|---|
|
Package adapters contains interoperability bridges with external runtimes.
|
Package adapters contains interoperability bridges with external runtimes. |
|
gocommand
Package gocommand provides compatibility helpers for wiring go-services command flows through github.com/goliatone/go-command registry/dispatcher.
|
Package gocommand provides compatibility helpers for wiring go-services command flows through github.com/goliatone/go-command registry/dispatcher. |
|
gojob
Package gojob provides compatibility adapters between go-services runtime contracts and github.com/goliatone/go-job queue/worker contracts.
|
Package gojob provides compatibility adapters between go-services runtime contracts and github.com/goliatone/go-job queue/worker contracts. |
|
gologger
Package gologger bridges go-services logging contracts with go-logger and go-job logger-provider adapters.
|
Package gologger bridges go-services logging contracts with go-logger and go-job logger-provider adapters. |
|
Package auth contains authentication strategy implementations.
|
Package auth contains authentication strategy implementations. |
|
Package command exposes transport-agnostic command handlers that wrap go-services mutating core operations and implement go-command.Commander[T].
|
Package command exposes transport-agnostic command handlers that wrap go-services mutating core operations and implement go-command.Commander[T]. |
|
Package core contains canonical services domain contracts, entities, and orchestration logic.
|
Package core contains canonical services domain contracts, entities, and orchestration logic. |
|
Package identity resolves normalized user profile fields from OAuth/OIDC credentials.
|
Package identity resolves normalized user profile fields from OAuth/OIDC credentials. |
|
Package inbound contains inbound surface handling abstractions.
|
Package inbound contains inbound surface handling abstractions. |
|
Package installations contains installation lifecycle orchestration.
|
Package installations contains installation lifecycle orchestration. |
|
Package oauth2 contains OAuth2 flow helpers and adapter logic.
|
Package oauth2 contains OAuth2 flow helpers and adapter logic. |
|
Package providers contains built-in provider implementations and factories.
|
Package providers contains built-in provider implementations and factories. |
|
devkit
Package devkit provides reusable fixtures and conformance helpers for provider integration development and testing.
|
Package devkit provides reusable fixtures and conformance helpers for provider integration development and testing. |
|
Package query exposes transport-agnostic read handlers that wrap go-services read-side operations and implement go-command.Querier[T, R].
|
Package query exposes transport-agnostic read handlers that wrap go-services read-side operations and implement go-command.Querier[T, R]. |
|
Package ratelimit contains rate-limit policy and quota state helpers.
|
Package ratelimit contains rate-limit policy and quota state helpers. |
|
Package security contains encryption and signing adapter implementations.
|
Package security contains encryption and signing adapter implementations. |
|
store
|
|
|
sql
Package sqlstore contains SQL-backed persistence adapters for core stores.
|
Package sqlstore contains SQL-backed persistence adapters for core stores. |
|
Package sync contains sync orchestration contracts and implementations.
|
Package sync contains sync orchestration contracts and implementations. |
|
Package transport contains protocol transport adapters used by providers.
|
Package transport contains protocol transport adapters used by providers. |
|
Package webhooks contains webhook verification and dispatch components.
|
Package webhooks contains webhook verification and dispatch components. |
|
Package worker contains worker runtime abstractions and adapters.
|
Package worker contains worker runtime abstractions and adapters. |
Click to show internal directories.
Click to hide internal directories.